==> kleinod-0.36-sources.jar: de/pfabulist/kleinod/nio/Pathss.java <==
package de.pfabulist.kleinod.nio;//package de.pfabulist.kleinod.nio;
//
//import java.io.IOException;
//import java.net.URI;
//import java.nio.file.*;
//import java.time.Clock;
//import java.time.Instant;
//import java.time.ZoneId;
//import java.time.format.DateTimeFormatter;
//import java.util.*;
//
//import static de.pfabulist.roast.unchecked.Unchecked.u;
//
///**
// * Copyright (c) 2006 - 2016, Stephan Pfab
// * SPDX-License-Identifier: BSD-2-Clause
// */
//public final class Pathss {
//
//    public static final String DEFAULT_FILESYSTEM_SCHEME = "file";
//
//    private Pathss() {}
//
//    public static Path getTmpDir( String prefix ) {
//
//        return FileSystems.getDefault().getPath( _nn(System.getProperty( "java.io.tmpdir" )),
//                                                 prefix + "-" + fsFriendlyName( Clock.systemUTC().instant() ) );
//    }
//
//    public static Pathh getTmpDirr( String prefix ) {
//
//        return Pathh.of( getTmpDir( prefix ) );
//    }
//
//    public static String fsFriendlyName( Instant inst ) {
//        return getDateTimeString( inst );//dtf.format(inst);
//    }
//
//    public static String getDateTimeString( final Instant instant ) {
//        DateTimeFormatter formatter =
//                DateTimeFormatter.ofPattern( "yyyy-MM-dd--HH-mm-ss--SSS" ).withZone( ZoneId.systemDefault() );
//        return formatter.format( instant );
//    }
//
//    public static FileSystem getOrCreate( URI uri, Map<String, ?> env ) {
//
//        String scheme = Optional.ofNullable( uri.getScheme() ).orElseThrow( () -> new IllegalArgumentException( "not a correct uri: " + uri ) );
//
//        if( scheme.equals( DEFAULT_FILESYSTEM_SCHEME ) ) {
//            return FileSystems.getDefault();
//        }
//        try {
//            return FileSystems.getFileSystem( uri );
//        } catch( FileSystemNotFoundException exp ) {
//            try {
//                return FileSystems.newFileSystem( uri, env );
//            } catch( IOException e ) {
//                throw u( e );
//            }
//        }
//    }
//
//    public static Path get( URI uri, Map<String, ?> env ) {
//        try {
//            // first try to unwrap it the nice way, because getOrCreate might not work even if the FS is already there
//            return Paths.get( uri );
//        } catch( FileSystemNotFoundException e ) {
//            getOrCreate( uri, env ); // create the filesystem if necessary and possible
//            return Paths.get( uri );
//        }
//    }
//
//    public static Path getPath( String str, Map<String, ?> env ) {
//        URI uri = URI.create( str );
//
//        if( uri.getScheme() == null ) {
//            throw new IllegalArgumentException( "not a uri with scheme " + uri );
//        }
//
//        return Pathss.get( uri, env );
//    }
//
//
//    public static void deleteRecursive( Path path ) {
//        if( !Files.exists( path ) ) {
//            return;
//        }
//
//        final Deque<Path> toDel = new ArrayDeque<>();
//
//        if( Files.isDirectory( path ) ) {
//            Filess.walk( path ).forEach( toDel::addFirst );
//        } else {
//            toDel.add( path );
//        }
//
//        toDel.stream().forEach( Filess::delete );
//    }
//
//
//
//    public static void copyRecursive( Path src, Path target, CopyOption... options ) {
//        if( !Files.exists( src ) ) {
//            return;
//        }
//
//        if( !Files.isDirectory( src ) ) {
//            Filess.copy( src, target, options );
//            return;
//        }
//
//        Filess.walk( src ).forEach( kid ->
//            {
//                Path to = target.resolve( src.relativize( kid ) );
//                Filess.copy( kid, to, options );
//            }
//        );
//
////        try {
////            Files.walkFileTree( src, new SimpleFileVisitor<Path>() {
////
////                @Override
////                public FileVisitResult visitFile( Path file,
////                                                  BasicFileAttributes attrs ) throws IOException {
////                    Path to = target.resolve( src.relativize( file ) );
////                    Files.copy( file, to );
////                    Files.setLastModifiedTime( to, Files.getLastModifiedTime( src ) ); // TODO others
////
////                    return FileVisitResult.CONTINUE;
////                }
////
////                @Override
////                public FileVisitResult preVisitDirectory( Path dir, BasicFileAttributes attrs ) throws IOException {
////                    Path to = target.resolve( src.relativize( dir ) );
////                    Files.copy( dir, to );
////                    Files.setLastModifiedTime( to, Files.getLastModifiedTime( src ) ); // TODO others
////
////                    return FileVisitResult.CONTINUE;
////                }
////
////            } );
////        } catch( IOException e ) {
////            throw u( e );
////        }
//
//    }
//
//    public static boolean isEmpty( Path dir ) {
//        try( DirectoryStream<Path> stream = Files.newDirectoryStream( dir ) ) {
//            return !stream.iterator().hasNext();
//        } catch( IOException e ) {
//            throw u( e );
//        }
//    }
//
//    public static boolean isRoot( Path path ) {
//        return path.isAbsolute() && path.getParent() == null;
//    }
//
//    public static boolean isRoot( Pathh path ) {
//        return path.isAbsolute() && !path.getParent().isPresent();
//    }
//
//    public static Pathh get( URI uri ) {
//        return Pathh.of( get( uri, Collections.emptyMap() ));
//    }
//}

==> kleinod-0.36.3-sources.jar: de/pfabulist/kleinod/nio/Pathss.java <==
package de.pfabulist.kleinod.nio;//package de.pfabulist.kleinod.nio;
//
//import java.io.IOException;
//import java.net.URI;
//import java.nio.file.*;
//import java.time.Clock;
//import java.time.Instant;
//import java.time.ZoneId;
//import java.time.format.DateTimeFormatter;
//import java.util.*;
//
//import static de.pfabulist.roast.unchecked.Unchecked.u;
//
///**
// * Copyright (c) 2006 - 2016, Stephan Pfab
// * SPDX-License-Identifier: BSD-2-Clause
// */
//public final class Pathss {
//
//    public static final String DEFAULT_FILESYSTEM_SCHEME = "file";
//
//    private Pathss() {}
//
//    public static Path getTmpDir( String prefix ) {
//
//        return FileSystems.getDefault().getPath( _nn(System.getProperty( "java.io.tmpdir" )),
//                                                 prefix + "-" + fsFriendlyName( Clock.systemUTC().instant() ) );
//    }
//
//    public static Pathh getTmpDirr( String prefix ) {
//
//        return Pathh.of( getTmpDir( prefix ) );
//    }
//
//    public static String fsFriendlyName( Instant inst ) {
//        return getDateTimeString( inst );//dtf.format(inst);
//    }
//
//    public static String getDateTimeString( final Instant instant ) {
//        DateTimeFormatter formatter =
//                DateTimeFormatter.ofPattern( "yyyy-MM-dd--HH-mm-ss--SSS" ).withZone( ZoneId.systemDefault() );
//        return formatter.format( instant );
//    }
//
//    public static FileSystem getOrCreate( URI uri, Map<String, ?> env ) {
//
//        String scheme = Optional.ofNullable( uri.getScheme() ).orElseThrow( () -> new IllegalArgumentException( "not a correct uri: " + uri ) );
//
//        if( scheme.equals( DEFAULT_FILESYSTEM_SCHEME ) ) {
//            return FileSystems.getDefault();
//        }
//        try {
//            return FileSystems.getFileSystem_( uri );
//        } catch( FileSystemNotFoundException exp ) {
//            try {
//                return FileSystems.newFileSystem_( uri, env );
//            } catch( IOException e ) {
//                throw u( e );
//            }
//        }
//    }
//
//    public static Path get( URI uri, Map<String, ?> env ) {
//        try {
//            // first try to unwrap it the nice way, because getOrCreate might not work even if the FS is already there
//            return Paths.get( uri );
//        } catch( FileSystemNotFoundException e ) {
//            getOrCreate( uri, env ); // create the filesystem if necessary and possible
//            return Paths.get( uri );
//        }
//    }
//
//    public static Path getPath( String str, Map<String, ?> env ) {
//        URI uri = URI.create( str );
//
//        if( uri.getScheme() == null ) {
//            throw new IllegalArgumentException( "not a uri with scheme " + uri );
//        }
//
//        return Pathss.get( uri, env );
//    }
//
//
//    public static void deleteRecursive( Path path ) {
//        if( !Files.exists( path ) ) {
//            return;
//        }
//
//        final Deque<Path> toDel = new ArrayDeque<>();
//
//        if( Files.isDirectory( path ) ) {
//            Filess.walk( path ).forEach( toDel::addFirst );
//        } else {
//            toDel.add( path );
//        }
//
//        toDel.stream().forEach( Filess::delete );
//    }
//
//
//
//    public static void copyRecursive( Path src, Path target, CopyOption... options ) {
//        if( !Files.exists( src ) ) {
//            return;
//        }
//
//        if( !Files.isDirectory( src ) ) {
//            Filess.copy( src, target, options );
//            return;
//        }
//
//        Filess.walk( src ).forEach( kid ->
//            {
//                Path to = target.resolve( src.relativize( kid ) );
//                Filess.copy( kid, to, options );
//            }
//        );
//
////        try {
////            Files.walkFileTree( src, new SimpleFileVisitor<Path>() {
////
////                @Override
////                public FileVisitResult visitFile( Path file,
////                                                  BasicFileAttributes attrs ) throws IOException {
////                    Path to = target.resolve( src.relativize( file ) );
////                    Files.copy( file, to );
////                    Files.setLastModifiedTime( to, Files.getLastModifiedTime( src ) ); // TODO others
////
////                    return FileVisitResult.CONTINUE;
////                }
////
////                @Override
////                public FileVisitResult preVisitDirectory( Path dir, BasicFileAttributes attrs ) throws IOException {
////                    Path to = target.resolve( src.relativize( dir ) );
////                    Files.copy( dir, to );
////                    Files.setLastModifiedTime( to, Files.getLastModifiedTime( src ) ); // TODO others
////
////                    return FileVisitResult.CONTINUE;
////                }
////
////            } );
////        } catch( IOException e ) {
////            throw u( e );
////        }
//
//    }
//
//    public static boolean isEmpty( Path dir ) {
//        try( DirectoryStream<Path> stream = Files.newDirectoryStream( dir ) ) {
//            return !stream.iterator().hasNext();
//        } catch( IOException e ) {
//            throw u( e );
//        }
//    }
//
//    public static boolean isRoot( Path path ) {
//        return path.isAbsolute() && path.getParent() == null;
//    }
//
//    public static boolean isRoot( Pathh path ) {
//        return path.isAbsolute() && !path.getParent().isPresent();
//    }
//
//    public static Pathh get( URI uri ) {
//        return Pathh.of( get( uri, Collections.emptyMap() ));
//    }
//}
